==> ejc-middlemeasurement-impl-3.0.0-20220412.090131-33-sources.jar: com/ejianc/business/middlemeasurement/bean/MechanicalleasedetotalEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.middlemeasurement.bean.MechanicalleasedetotaldetailEntity;
/**
 * 月度机械设备租赁结算汇总
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_mechanicalleasedetotal")
public class MechanicalleasedetotalEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="ex_tax_month_settlement")
    private java.math.BigDecimal exTaxMonthSettlement; // 本月结算金额(除税)
    @TableField(value="in_tax_month_settlement")
    private java.math.BigDecimal inTaxMonthSettlement; // 本月结算金额(含税)
    @TableField(value="ex_tax_cumulative_settlement")
    private java.math.BigDecimal exTaxCumulativeSettlement; // 累计结算(除税)
    @TableField(value="in_tax_cumulative_settlement")
    private java.math.BigDecimal inTaxCumulativeSettlement; // 累计结算(含税)
    @TableField(value="ex_tax_cumulative_due")
    private java.math.BigDecimal exTaxCumulativeDue; // 本月累计应付款金额
    @TableField(value="in_tax_cumulative_paid")
    private java.math.BigDecimal inTaxCumulativePaid; // 本月累计付款金额
    @TableField(value="statistical_time")
    private java.util.Date statisticalTime; // 统计时间
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="mechanicalleasedetotaldetailService",pidName = "mid")
    private List<MechanicalleasedetotaldetailEntity> mechanicalleasedetotaldetailEntities = new ArrayList<>(); // 月度机械设备租赁结算汇总子表
    

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 本月结算金额(除税)
     */
    public java.math.BigDecimal getExTaxMonthSettlement() {
        return exTaxMonthSettlement;
    }

    /**
     * 本月结算金额(除税)
     */
    public void setExTaxMonthSettlement(java.math.BigDecimal exTaxMonthSettlement) {
        this.exTaxMonthSettlement = exTaxMonthSettlement;
    }
    /**
     * 本月结算金额(含税)
     */
    public java.math.BigDecimal getInTaxMonthSettlement() {
        return inTaxMonthSettlement;
    }

    /**
     * 本月结算金额(含税)
     */
    public void setInTaxMonthSettlement(java.math.BigDecimal inTaxMonthSettlement) {
        this.inTaxMonthSettlement = inTaxMonthSettlement;
    }
    /**
     * 累计结算(除税)
     */
    public java.math.BigDecimal getExTaxCumulativeSettlement() {
        return exTaxCumulativeSettlement;
    }

    /**
     * 累计结算(除税)
     */
    public void setExTaxCumulativeSettlement(java.math.BigDecimal exTaxCumulativeSettlement) {
        this.exTaxCumulativeSettlement = exTaxCumulativeSettlement;
    }
    /**
     * 累计结算(含税)
     */
    public java.math.BigDecimal getInTaxCumulativeSettlement() {
        return inTaxCumulativeSettlement;
    }

    /**
     * 累计结算(含税)
     */
    public void setInTaxCumulativeSettlement(java.math.BigDecimal inTaxCumulativeSettlement) {
        this.inTaxCumulativeSettlement = inTaxCumulativeSettlement;
    }
    /**
     * 本月累计应付款金额
     */
    public java.math.BigDecimal getExTaxCumulativeDue() {
        return exTaxCumulativeDue;
    }

    /**
     * 本月累计应付款金额
     */
    public void setExTaxCumulativeDue(java.math.BigDecimal exTaxCumulativeDue) {
        this.exTaxCumulativeDue = exTaxCumulativeDue;
    }
    /**
     * 本月累计付款金额
     */
    public java.math.BigDecimal getInTaxCumulativePaid() {
        return inTaxCumulativePaid;
    }

    /**
     * 本月累计付款金额
     */
    public void setInTaxCumulativePaid(java.math.BigDecimal inTaxCumulativePaid) {
        this.inTaxCumulativePaid = inTaxCumulativePaid;
    }
    
    /**
     * 月度机械设备租赁结算汇总子表
     */
    public List<MechanicalleasedetotaldetailEntity> getMechanicalleasedetotaldetailEntities() {
        return mechanicalleasedetotaldetailEntities;
    }

    /**
     * 月度机械设备租赁结算汇总子表
     */
    public void setMechanicalleasedetotaldetailEntities(List<MechanicalleasedetotaldetailEntity> mechanicalleasedetotaldetailEntities) {
        this.mechanicalleasedetotaldetailEntities = mechanicalleasedetotaldetailEntities;
    }

    public Date getStatisticalTime() {
        return statisticalTime;
    }

    public void setStatisticalTime(Date statisticalTime) {
        this.statisticalTime = statisticalTime;
    }
}

==> ejc-middlemeasurement-impl-3.0.0-20220428.022448-70-sources.jar: com/ejianc/business/middlemeasurement/bean/MechanicalleasedetotalEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.middlemeasurement.bean.MechanicalleasedetotaldetailEntity;
/**
 * 月度机械设备租赁结算汇总
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_mechanicalleasedetotal")
public class MechanicalleasedetotalEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="ex_tax_month_settlement")
    private java.math.BigDecimal exTaxMonthSettlement; // 本月结算金额(除税)
    @TableField(value="in_tax_month_settlement")
    private java.math.BigDecimal inTaxMonthSettlement; // 本月结算金额(含税)
    @TableField(value="ex_tax_cumulative_settlement")
    private java.math.BigDecimal exTaxCumulativeSettlement; // 累计结算(除税)
    @TableField(value="in_tax_cumulative_settlement")
    private java.math.BigDecimal inTaxCumulativeSettlement; // 累计结算(含税)
    @TableField(value="ex_tax_cumulative_due")
    private java.math.BigDecimal exTaxCumulativeDue; // 本月累计应付款金额
    @TableField(value="in_tax_cumulative_paid")
    private java.math.BigDecimal inTaxCumulativePaid; // 本月累计付款金额
    @TableField(value="statistical_time")
    private java.util.Date statisticalTime; // 统计时间
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="mechanicalleasedetotaldetailService",pidName = "mid")
    private List<MechanicalleasedetotaldetailEntity> mechanicalleasedetotaldetailEntities = new ArrayList<>(); // 月度机械设备租赁结算汇总子表

    @TableField(exist = false)
    private List<String> referenceIdList = new ArrayList<>(); // 被引用的月度周采购结算单id集合

    public List<String> getReferenceIdList() {
        return referenceIdList;
    }

    public void setReferenceIdList(List<String> referenceIdList) {
        this.referenceIdList = referenceIdList;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 本月结算金额(除税)
     */
    public java.math.BigDecimal getExTaxMonthSettlement() {
        return exTaxMonthSettlement;
    }

    /**
     * 本月结算金额(除税)
     */
    public void setExTaxMonthSettlement(java.math.BigDecimal exTaxMonthSettlement) {
        this.exTaxMonthSettlement = exTaxMonthSettlement;
    }
    /**
     * 本月结算金额(含税)
     */
    public java.math.BigDecimal getInTaxMonthSettlement() {
        return inTaxMonthSettlement;
    }

    /**
     * 本月结算金额(含税)
     */
    public void setInTaxMonthSettlement(java.math.BigDecimal inTaxMonthSettlement) {
        this.inTaxMonthSettlement = inTaxMonthSettlement;
    }
    /**
     * 累计结算(除税)
     */
    public java.math.BigDecimal getExTaxCumulativeSettlement() {
        return exTaxCumulativeSettlement;
    }

    /**
     * 累计结算(除税)
     */
    public void setExTaxCumulativeSettlement(java.math.BigDecimal exTaxCumulativeSettlement) {
        this.exTaxCumulativeSettlement = exTaxCumulativeSettlement;
    }
    /**
     * 累计结算(含税)
     */
    public java.math.BigDecimal getInTaxCumulativeSettlement() {
        return inTaxCumulativeSettlement;
    }

    /**
     * 累计结算(含税)
     */
    public void setInTaxCumulativeSettlement(java.math.BigDecimal inTaxCumulativeSettlement) {
        this.inTaxCumulativeSettlement = inTaxCumulativeSettlement;
    }
    /**
     * 本月累计应付款金额
     */
    public java.math.BigDecimal getExTaxCumulativeDue() {
        return exTaxCumulativeDue;
    }

    /**
     * 本月累计应付款金额
     */
    public void setExTaxCumulativeDue(java.math.BigDecimal exTaxCumulativeDue) {
        this.exTaxCumulativeDue = exTaxCumulativeDue;
    }
    /**
     * 本月累计付款金额
     */
    public java.math.BigDecimal getInTaxCumulativePaid() {
        return inTaxCumulativePaid;
    }

    /**
     * 本月累计付款金额
     */
    public void setInTaxCumulativePaid(java.math.BigDecimal inTaxCumulativePaid) {
        this.inTaxCumulativePaid = inTaxCumulativePaid;
    }
    
    /**
     * 月度机械设备租赁结算汇总子表
     */
    public List<MechanicalleasedetotaldetailEntity> getMechanicalleasedetotaldetailEntities() {
        return mechanicalleasedetotaldetailEntities;
    }

    /**
     * 月度机械设备租赁结算汇总子表
     */
    public void setMechanicalleasedetotaldetailEntities(List<MechanicalleasedetotaldetailEntity> mechanicalleasedetotaldetailEntities) {
        this.mechanicalleasedetotaldetailEntities = mechanicalleasedetotaldetailEntities;
    }

    public Date getStatisticalTime() {
        return statisticalTime;
    }

    public void setStatisticalTime(Date statisticalTime) {
        this.statisticalTime = statisticalTime;
    }
}
